@@ -15,7 +15,33 @@ from urllib2 import urlopen
 import nltk
 
 from .es import fetch
-from ..celery import app
+from ..core import app
+from .._utils import nltk_download
+
+
+@app.task
+def guess_language(doc, output="best"):
+    """Guess the language of a document.
+
+    Uses the langid library.
+
+    Parameters
+    ----------
+    doc : document
+
+    output : string
+        Either "best" to get a pair (code, prob) giving the two-letter code
+        of the most probable language and its probability, or "rank" for a
+        list of such pairs for all languages in the model.
+    """
+    from langid import classify, rank
+
+    try:
+        func = {"best": classify, "rank": rank}[output]
+    except KeyError:
+        raise ValueError("invalid parameter value output=%r" % output)
+
+    return func(fetch(doc))
 
 
 @app.task
@@ -31,7 +57,7 @@ def morphy(doc):
     """
     # XXX Results will be better if we do POS tagging first, but then we
     # need to map Penn Treebank tags to WordNet tags.
-    nltk.download('wordnet', quiet=False)
+    nltk_download('wordnet')
     return map(nltk.WordNetLemmatizer().lemmatize,
                _tokenize_if_needed(fetch(doc)))
 
@@ -97,7 +123,7 @@ def pos_tag(tokens, model='nltk'):
     """
     if model != 'nltk':
         raise ValueError("unknown POS tagger %r" % model)
-    nltk.download('maxent_treebank_pos_tagger')
+    nltk_download('maxent_treebank_pos_tagger')
     return nltk.pos_tag([t["token"] for t in tokens])
 
 
